gchecky.model

Package gchecky :: Module model |
[hide private]
[frames] | no frames]

# Module model

source code

gchecky.model module describes the mapping between Google Checkout API (GC API) XML messages (GC API XML Schema) and data classes.

This module uses gchecky.gxml to automate much of the work so that the actual logic is not cluttered with machinery.

The module code is simple and self-documenting. Please read the source code for simple description of the data-structures. Note that it tries to follow exactly the official GC API XML Schema.

All the comments for the GC API are at Google Chackout API documentation. Please consult it for any questions about GC API functioning.

Author: etarassov

Version: $Revision: 91 $

Contact: gchecky at gmail

Classes | [hide private]
| price_t
| digital_content_t
| item_t
| postal_area_t
| tax_area_t
| areas_t Represents a list of regions.
| allowed_areas_t
| excluded_areas_t
| tax_rule_t
| default_tax_rule_t
| alternate_tax_rule_t
| default_tax_table_t
| alternate_tax_table_t
| tax_tables_t
| merchant_calculations_t
| shipping_option_t Represents information about shipping costs.
| flat_rate_shipping_t
| merchant_calculated_shipping_t
| pickup_t
| shipping_methods_t
| url_parameter_t
| parameterized_url_t
| checkout_flow_support_t
| shopping_cart_t
| hello_t Represents a simple test that verifies that your server communicates properly with Google Checkout.
| bye_t Represents a response that indicates that Google correctly received a <hello> request.
| checkout_shopping_cart_t
| coupon_gift_adjustment_t
| merchant_codes_t
| shipping_adjustment_t
| shipping_in_order_adjustment_t
| shipping_in_calculate_t
| order_adjustment_t
| address_t
| buyer_billing_address_t
| buyer_shipping_address_t
| billing_address_t
| buyer_marketing_preferences_t
| abstract_notification_t
| new_order_notification_t
| checkout_redirect_t Try doctests: >>> a = checkout_redirect_t(serial_number='blabla12345', ...
| notification_acknowledgment_t
| order_state_change_notification_t
| risk_information_t
| risk_information_notification_t
| abstract_order_t
| charge_order_t
| refund_order_t
| cancel_order_t Represents an order that should be canceled.
| authorize_order_t
| process_order_t
| add_merchant_order_number_t
| tracking_data_t
| deliver_order_t
| add_tracking_data_t Represents a tag containing a request to add a shipper's tracking number to an order.
| send_buyer_message_t
| archive_order_t Represents a request to archive a particular order.
| unarchive_order_t
| charge_amount_notification_t Represents information about a successful charge for an order.
| refund_amount_notification_t
| chargeback_amount_notification_t
| authorization_amount_notification_t
| anonymous_address_t
| merchant_code_string_t
| calculate_t
| merchant_calculation_callback_t
| discount_result_t
| merchant_code_results_t
| result_t
| merchant_calculation_results_t
| request_received_t
| ok_t
| error_t Represents a response containing information about an invalid API request.
| diagnosis_t Represents a diagnostic response to an API request.
| demo_failure_t

Functions | [hide private]
test_document(doc, xml_text=None) Method used in doctests: ensures that a document is properly serialized. | source code
test_node(node, xml_text=None) Method used in doctests. | source code

Variables | [hide private]
| CURRENCIES = ``(``'``USD``'``,` `'``GBP``'``)``
| DISPLAY_DISPOSITION = ``(``'``OPTIMISTIC``'``,` `'``PESSIMISTIC``'``)``
| URL_PARAMETER_TYPES = ``(``'``buyer-id``'``,` `'``order-id``'``,` `'``order-subtotal``...``
| FINANCIAL_ORDER_STATE = ``(``'``REVIEWING``'``,` `'``CHARGEABLE``'``,` `'``CHARGING``'``...``
| FULFILLMENT_ORDER_STATE = ``(``'``NEW``'``,` `'``PROCESSING``'``,` `'``DELIVERED``'``,` `'``...``
| AVS_VALUES = ``(``'``Y``'``,` `'``P``'``,` `'``A``'``,` `'``N``'``,` `'``U``'``)``
| CVN_VALUES = ``(``'``M``'``,` `'``N``'``,` `'``U``'``,` `'``E``'``)``
| CARRIER_VALUES = ``(``'``DHL``'``,` `'``FedEx``'``,` `'``UPS``'``,` `'``USPS``'``,` `'``Other``'``)``

Function Details | [hide private]

### test_node(node, xml_text=None) | source code
Method used in doctests. Ensure that a node is properly serialized.

Variables Details | [hide private]

  ### URL_PARAMETER_TYPES Value:
      ('buyer-id',
       'order-id',
       'order-subtotal',
       'order-subtotal-plus-tax',
       'order-subtotal-plus-shipping',
       'order-total',
       'tax-amount',
       'shipping-amount',
      ...

  ### FINANCIAL_ORDER_STATE Value:
      ('REVIEWING',
       'CHARGEABLE',
       'CHARGING',
       'CHARGED',
       'PAYMENT_DECLINED',
       'CANCELLED',
       'CANCELLED_BY_GOOGLE')

  ### FULFILLMENT_ORDER_STATE Value:
      ('NEW', 'PROCESSING', 'DELIVERED', 'WILL_NOT_DELIVER')